CreateStatus200Response class

Constructors

CreateStatus200Response({required CreateStatus200ResponseType statusType, Status? status, ScheduledStatus? scheduledStatus})
CreateStatus200Response.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduledStatus → ScheduledStatus?
final
status → Status?
final
statusType → CreateStatus200ResponseType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited