CreateStatusRequest class

Constructors

CreateStatusRequest({required CreateStatusRequestType type, TextStatus? text, PollStatus? poll, MediaStatus? media})
CreateStatusRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
media → MediaStatus?
final
poll → PollStatus?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → TextStatus?
final
type → CreateStatusRequestType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited