TextStatus class

Available extensions
Annotations
  • @CopyWith.new()
  • @JsonSerializable.new(checked: true, createToJson: true, disallowUnrecognizedKeys: false, explicitToJson: true)

Constructors

TextStatus({required String status, String? inReplyToId, String? language, String? quoteApprovalPolicy, String? quotedStatusId, DateTime? scheduledAt, bool? sensitive = false, String? spoilerText, StatusVisibilityEnum? visibility})
Returns a new TextStatus instance.
TextStatus.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → _$TextStatusCWProxy

Available on TextStatus, provided by the $TextStatusCopyWith extension

Returns a callable class used to build a new instance with modified fields. Example: instanceOfTextStatus.copyWith(...) or instanceOfTextStatus.copyWith.fieldName(...).
no setter
hashCode int
The hash code for this object.
no setteroverride
inReplyToId String?
ID of the status being replied to, if status is a reply.
final
language String?
ISO 639-1 language code for this status.
final
quoteApprovalPolicy String?
String (Enumerable, oneOf). Sets who is allowed to quote the status. When omitted, the user's default setting will be used instead. Ignored if visibility is private or direct, in which case the policy will always be set to nobody.
final
quotedStatusId String?
ID of the status being quoted, if any. Will raise an error if the status does not exist, the author does not have access to it, or quoting is denied by Mastodon's understanding of the attached quote policy. All posts except Private Mentions (direct visibility) are quotable by their author. Quoting a private post will restrict the quoting post's visibility to private or direct (if the given visibility is public or unlisted, private will be used instead). An error will be returned when making a quote post with direct visibility and the quote author is not explicitly mentioned. If the status text doesn't include a link to the quoted post, Mastodon will prepend a <p class=\"quote-inline\">RE: <a href=\"…\">…</a></p> paragraph for backward compatibility (such a paragraph will be hidden by Mastodon's web interface).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheduledAt DateTime?
Datetime at which to schedule a status. Providing this parameter will cause ScheduledStatus to be returned instead of Status. Must be at least 5 minutes in the future.
final
sensitive bool?
Mark status and attached media as sensitive? Defaults to false.
final
spoilerText String?
Text to be shown as a warning or subject before the actual content. Statuses are generally collapsed behind this field.
final
status String
The text content of the status. If media_ids is provided, this becomes optional. Attaching a poll is optional while status is provided.
final
visibility StatusVisibilityEnum?
Sets the visibility of the posted status to public, unlisted, private, direct.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override