PaginationLinks class final

Links advertised by an HTTP Link response header.

Constructors

PaginationLinks.fromHeaderValues(Iterable<String> values)
Parses one or more HTTP Link header field values.
factory
PaginationLinks.parse(String? value)
Parses one HTTP Link header field value.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether the response advertised no link relations.
no setter
isNotEmpty → bool
Whether the response advertised at least one link relation.
no setter
next → PaginationLink?
The first link with the next relation, if present.
no setter
prev → PaginationLink?
The first link with the prev relation, if present.
no setter
previous → PaginationLink?
The first link with the prev relation, if present.
no setter
relations → Map<String, List<Uri>>
Link targets grouped by their rel value.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](String relation) → List<Uri>
Returns all targets advertised for relation.

Constants

empty → const PaginationLinks
No pagination links.