PaginationLink class final
A Mastodon pagination target and its cursor parameters.
Constructors
- PaginationLink(Uri uri)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit → int?
-
The requested maximum number of results.
no setter
- maxId → String?
-
Return results older than this ID.
no setter
- minId → String?
-
Return results immediately newer than this ID.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sinceId → String?
-
Return results newer than this ID.
no setter
- uri → Uri
-
The complete pagination target.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited